Features
============

There are following fundamental features:

* Internationalization and localization
* Google Analytics is connected
* Sitemap.xml is generated on fly
* Two fully responsive :ref:`themes <Themes>` out of the box
* Switching between the themes from admin
* User interface that `"Don't make me think" <http://en.wikipedia.org/wiki/Don%27t_Make_Me_Think/>`_  
* Additional dynamic menu like a mix of "cloud of links" and "bread crumbs"
* REST API with `REST API Client on PHP, Java, Python <http://mysmile.com.ua/en/download.html/>`_
* Unlimited number of pages


The following are SEO features:

* HTML5 semantic
* Sitemap.xml
* Robots.txt
* Friendly :ref:`Urls`
* Meta tags
* Alt attribute for images


.. seealso::

   :ref:`SEO_configuration` 
